% Script file to generate a figure of the projection-based reachability of
% the generator example for the ACC submission.
%
% Ian Mitchell, 8/27/07.

  % Now run the reach set.  This takes a while.
  [ all_data, g ] = projReachOneGen('veryHigh', 1);

  % A new figure to plot the results.
  fig = figure;
  hold on;
  for i = 1 : length(all_data)
    % Plot each timestep's contour to give some idea of the growing reach set.
    % Don't forget to unscale the E_fd dimension.
    [ garbage, hc ] = contour(g.xs{1}, 10 * g.xs{2}, all_data{i}, ...
                              [ 0 0 ], 'k-');
  end
  
  % Plot the converse of the final reach set filled.
  [ garbage, hf ] = contourf(g.xs{1}, 10 * g.xs{2}, all_data{end}, [ 0 0 ]);
  % Plot the initial target set filled.
  [ garbage, hf ] = contourf(g.xs{1}, 10 * g.xs{2}, -all_data{1} + 1, [ 1 1 ]);
  colormap([ 0.9 * ones(1,3); 0.5 * ones(1,3) ]);

  % Now finish with the simulated trajectories.
  [ ts, ys ] = simulateOneGen;
  figure(fig);
  for i = 1 : length(ts)
    % Plot only in the E vs E_fd state space.
    ht = plot(ys{i}(:,1), ys{i}(:,3), 'r--');
    set(ht, 'LineWidth', 2);
  end
  
  % We'll adjust the aspect ratio and axes sizes slightly.
  axis tight;
  axis([ 0.6, 1.400001, -0, 6 ]);
  set(gca, 'FontSize', 20);
  xlabel('x_1 = E'); ylabel('x_2 = E_f');
  daspect([ 1 10 1 ]);
  grid on;
  
